@@ -70,8 +70,6 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
     level = 1
     # ordered list of options to control the ckecker behaviour
     options = ()
-    # checker that should be run before this one
-    needs_checkers = ()
     # messages issued by this checker
     msgs = {}
     # reports issued by this checker
@@ -86,6 +84,8 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
         self.name = self.name.lower()
         OptionsProviderMixIn.__init__(self)
         self.linter = linter
+        # messages that are active for the current check
+        self.active_msgs = set()
 
     def add_message(self, msg_id, line=None, node=None, args=None):
         """add a message of a given type"""
@@ -107,13 +107,15 @@ class BaseChecker(OptionsProviderMixIn, ASTWalker):
 class BaseRawChecker(BaseChecker):
     """base class for raw checkers"""
 
-    def process_module(self, stream):
+    def process_module(self, node):
         """process a module
 
         the module's content is accessible via the stream object
 
         stream must implement the readline method
         """
+        stream = node.file_stream
+        stream.seek(0)
         self.process_tokens(tokenize.generate_tokens(stream.readline))
 
     def process_tokens(self, tokens):
@@ -145,9 +147,9 @@ def package_load(linter, directory):
             except ValueError:
                 # empty module name (usually emacs auto-save files)
                 continue
-            except ImportError:
+            except ImportError, exc:
                 import sys
-                print >> sys.stderr, "Problem importing module: %s" % filename
+                print >> sys.stderr, "Problem importing module %s: %s" % (filename, exc)
             else:
                 if hasattr(module, 'register'):
                     module.register(linter)
