@@ -21,7 +21,7 @@ from logilab.astng import InferenceError, NotFoundError, YES, Instance
 
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import safe_infer, is_super
+from pylint.checkers.utils import safe_infer, is_super, check_messages
 
 MSGS = {
     'E1101': ('%s %r has no %r member',
@@ -113,6 +113,7 @@ accessed.'}
     def visit_delattr(self, node):
         self.visit_getattr(node)
 
+    @check_messages('E1101', 'E1103')
     def visit_getattr(self, node):
         """check that the accessed attribute exists
 
@@ -160,8 +161,7 @@ accessed.'}
                 if isinstance(owner, Instance) and owner.has_dynamic_getattr():
                     continue
                 # explicit skipping of optparse'Values class
-                if owner.name == 'Values' and \
-                       owner.root().name in ('optik', 'optparse'):
+                if owner.name == 'Values' and owner.root().name == 'optparse':
                     continue
                 missingattr.add((owner, name))
                 continue
