@@ -16,16 +16,17 @@
 """variables checkers for Python code
 """
 
+import sys
 from copy import copy
 
 from logilab import astng
-from logilab.astng import are_exclusive, builtin_lookup
+from logilab.astng import are_exclusive, builtin_lookup, ASTNGBuildingException
 
 from pylint.interfaces import IASTNGChecker
 from pylint.checkers import BaseChecker
-from pylint.checkers.utils import PYMETHODS, is_ancestor_name, is_builtin, \
-     is_defined_before, is_error, is_func_default, is_func_decorator, assign_parent
-
+from pylint.checkers.utils import (PYMETHODS, is_ancestor_name, is_builtin,
+     is_defined_before, is_error, is_func_default, is_func_decorator,
+     assign_parent, check_messages)
 
 def overridden_method(klass, name):
     """get overridden method if any"""
@@ -136,6 +137,7 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 # do not print Redefining builtin for additional builtins
                 self.add_message('W0622', args=name, node=stmts[0])
 
+    @check_messages('W0611', 'W0614')
     def leave_module(self, node):
         """leave module: check globals
         """
@@ -214,6 +216,10 @@ builtins. Remember that you should avoid to define new builtins when possible.'
     def visit_function(self, node):
         """visit function: update consumption analysis variable and check locals
         """
+        self._to_consume.append((copy(node.locals), {}, 'function'))
+        self._vars.append({})
+        if not set(('W0621', 'W0622')) & self.active_msgs:
+            return
         globs = node.root().globals
         for name, stmt in node.items():
             if name in globs and not isinstance(stmt, astng.Global):
@@ -222,13 +228,13 @@ builtins. Remember that you should avoid to define new builtins when possible.'
             elif is_builtin(name):
                 # do not print Redefining builtin for additional builtins
                 self.add_message('W0622', args=name, node=stmt)
-        self._to_consume.append((copy(node.locals), {}, 'function'))
-        self._vars.append({})
 
     def leave_function(self, node):
         """leave function: check function's locals are consumed"""
         not_consumed = self._to_consume.pop()[0]
         self._vars.pop(0)
+        if not set(('W0612', 'W0613')) & self.active_msgs:
+            return
         # don't check arguments of function which are only raising an exception
         if is_error(node):
             return
@@ -238,7 +244,7 @@ builtins. Remember that you should avoid to define new builtins when possible.'
         if is_method and (klass.type == 'interface' or node.is_abstract()):
             return
         authorized_rgx = self.config.dummy_variables_rgx
-        overridden = marker = []
+        called_overridden = False
         argnames = node.argnames()
         for name, stmts in not_consumed.iteritems():
             # ignore some special names specified by user configuration
@@ -256,8 +262,9 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                     if node.type != 'staticmethod' and name == argnames[0]:
                         continue
                     # don't warn for argument of an overridden method
-                    if overridden is marker:
+                    if not called_overridden:
                         overridden = overridden_method(klass, node.name)
+                        called_overridden = True
                     if overridden is not None and name in overridden.argnames():
                         continue
                     if node.name in PYMETHODS and node.name not in ('__init__', '__new__'):
@@ -269,6 +276,7 @@ builtins. Remember that you should avoid to define new builtins when possible.'
             else:
                 self.add_message('W0612', args=name, node=stmt)
 
+    @check_messages('W0601', 'W0602', 'W0603', 'W0604', 'W0622')
     def visit_global(self, node):
         """check names imported exists in the global scope"""
         frame = node.frame()
@@ -319,6 +327,8 @@ builtins. Remember that you should avoid to define new builtins when possible.'
         #astmts = [stmt for stmt in node.lookup(name)[1]
         #          if hasattr(stmt, 'ass_type')] and
         #          not stmt.statement().parent_of(node)]
+        if 'W0631' not in self.active_msgs:
+            return
         astmts = [stmt for stmt in node.lookup(name)[1]
                   if hasattr(stmt, 'ass_type')]
         # filter variables according their respective scope
@@ -429,6 +439,7 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                     or name in self.config.additional_builtins):
                 self.add_message('E0602', args=name, node=node)
 
+    @check_messages('E0611')
     def visit_import(self, node):
         """check modules attribute accesses"""
         for name, _ in node.names:
@@ -439,14 +450,16 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 continue
             self._check_module_attrs(node, module, parts[1:])
 
+    @check_messages('E0611')
     def visit_from(self, node):
         """check modules attribute accesses"""
         name_parts = node.modname.split('.')
         try:
             module = node.root().import_module(name_parts[0])
-        except KeyboardInterrupt:
-            raise
-        except:
+        except ASTNGBuildingException:
+            return
+        except Exception, exc:
+            print 'Unhandled exception in VariablesChecker:', exc
             return
         module = self._check_module_attrs(node, module, name_parts[1:])
         if not module:
@@ -456,31 +469,6 @@ builtins. Remember that you should avoid to define new builtins when possible.'
                 continue
             self._check_module_attrs(node, module, name.split('.'))
 
-##     def leave_getattr(self, node):
-##         """check modules attribute accesses
-
-##         this function is a "leave_" because when parsing 'a.b.c'
-##         we want to check the innermost expression first.
-##         """
-##         if isinstance(node.expr, astng.Name):
-##             try:
-##                 module = node.expr.infer().next()
-##             except astng.InferenceError:
-##                 return
-##             if not isinstance(module, astng.Module):
-##                 # Not a module, don't check
-##                 return
-##         elif self._checking_mod_attr is not None:
-##             module = self._checking_mod_attr
-##         else:
-##             return
-##         self._checking_mod_attr = self._check_module_attrs(node, module,
-##                                                            [node.attrname])
-
-##     def leave_default(self, node):
-##         """by default, reset the _checking_mod_attr attribute"""
-##         self._checking_mod_attr = None
-
     def _check_module_attrs(self, node, module, module_names):
         """check that module_names (list of string) are accessible through the
         given module
@@ -526,7 +514,6 @@ class VariablesChecker3k(VariablesChecker):
         # do not check for not used locals here
         self._to_consume.pop()
 
-import sys
 if sys.version_info >= (3, 0):
     VariablesChecker = VariablesChecker3k
 
