@@ -42,10 +42,9 @@ from logilab.common.modutils import load_module_from_name
 from logilab.common.interface import implements
 from logilab.common.textutils import splitstrip
 from logilab.common.ureports import Table, Text, Section
-from logilab.common.graph import ordered_nodes
 from logilab.common.__pkginfo__ import version as common_version
 
-from logilab.astng import MANAGER, nodes
+from logilab.astng import MANAGER, nodes, ASTNGBuildingException
 from logilab.astng.__pkginfo__ import version as astng_version
 
 from pylint.utils import PyLintASTWalker, UnknownMessage, MessagesHandlerMixIn,\
@@ -85,6 +84,10 @@ MSGS = {
     'F0004': ('unexpected inferred value %s',
               'Used to indicate that some value of an unexpected type has been \
               inferred.'),
+    'F0010': ('error while code parsing: %s',
+              'Used when an exception occured while building the ASTNG \
+               representation which could be handled by astng.'),
+
 
     'I0001': ('Unable to run raw checkers on built-in module %s',
               'Used to inform that a built-in module has not been checked \
@@ -315,9 +318,8 @@ This is used by the global evaluation report (RP0004).'}),
         """
         assert checker.priority <= 0, 'checker priority can\'t be >= 0'
         self._checkers.setdefault(checker.name, []).append(checker)
-        if hasattr(checker, 'reports'):
-            for r_id, r_title, r_cb in checker.reports:
-                self.register_report(r_id, r_title, r_cb, checker)
+        for r_id, r_title, r_cb in checker.reports:
+            self.register_report(r_id, r_title, r_cb, checker)
         self.register_options_provider(checker)
         if hasattr(checker, 'msgs'):
             self.register_messages(checker)
@@ -332,6 +334,19 @@ This is used by the global evaluation report (RP0004).'}),
                 for msgid in msgids:
                     self.disable(msgid)
 
+    def disable_reporters(self):
+       """disable all reporters"""
+       for reporters in self._reports.values():
+           for report_id, _title, _cb in reporters:
+               self.disable_report(report_id)
+
+    def error_mode(self):
+        """error mode: enable only errors; no reports, no persistent"""
+        self.disable_noerror_messages()
+        self.disable('miscellaneous')
+        self.set_option('reports', False)
+        self.set_option('persistent', False)
+
     # block level option handling #############################################
     #
     # see func_block_disable_msg.py test case for expected behaviour
@@ -364,8 +379,8 @@ This is used by the global evaluation report (RP0004).'}),
                     meth = self._options_methods[opt]
                 except KeyError:
                     meth = self._bw_options_methods[opt]
-                    warn('%s is deprecated, replace it by %s (%s)' % (
-                        opt, opt.split('-')[0], self.current_file),
+                    warn('%s is deprecated, replace it by %s (%s, line %s)' % (
+                        opt, opt.split('-')[0], self.current_file, line),
                          DeprecationWarning)
                 for msgid in splitstrip(value):
                     try:
@@ -422,35 +437,25 @@ This is used by the global evaluation report (RP0004).'}),
 
     # code checking methods ###################################################
 
-    def sort_checkers(self, checkers=None):
-        if checkers is None:
-            checkers = [checker for checkers in self._checkers.values()
-                        for checker in checkers]
-        graph = {}
-        cls_instance = {}
-        for checker in checkers:
-            graph[checker.__class__] = set(checker.needs_checkers)
-            cls_instance[checker.__class__] = checker
-        checkers = [cls_instance.get(cls) for cls in ordered_nodes(graph)]
-        checkers.remove(self)
-        checkers.insert(0, self)
-        return checkers
+    def get_checkers(self):
+        """return all available checkers as a list"""
+        return [self] + [c for checkers in self._checkers.values()
+                         for c in checkers if c is not self]
 
-    def _get_checkers(self):
-        # compute checkers needed according to activated messages and reports
-        neededcheckers = set()
-        for checkers in self._checkers.values():
-            for checker in checkers:
-                for msgid in checker.msgs:
-                    if self._msgs_state.get(msgid, True):
-                        neededcheckers.add(checker)
-                        break
-                else:
-                    for reportid, _, _ in checker.reports:
-                        if self.is_report_enabled(reportid):
-                            neededcheckers.add(checker)
-                            break
-        return self.sort_checkers(neededcheckers)
+    def prepare_checkers(self):
+        """return checkers needed for activated messages and reports"""
+        if not self.config.reports:
+            self.disable_reporters()
+        # get needed checkers
+        neededcheckers = [self]
+        for checker in self.get_checkers()[1:]:
+            messages = set(msg for msg in checker.msgs
+                           if self.is_message_enabled(msg))
+            if (messages or
+                any(self.report_is_enabled(r[0]) for r in checker.reports)):
+                neededcheckers.append(checker)
+                checker.active_msgs = messages
+        return neededcheckers
 
     def check(self, files_or_modules):
         """main checking entry: check a list of files or modules from their
@@ -459,16 +464,15 @@ This is used by the global evaluation report (RP0004).'}),
         self.reporter.include_ids = self.config.include_ids
         if not isinstance(files_or_modules, (list, tuple)):
             files_or_modules = (files_or_modules,)
-        checkers = self._get_checkers()
-        rawcheckers = []
-        walker = PyLintASTWalker()
+        walker = PyLintASTWalker(self)
+        checkers = self.prepare_checkers()
+        rawcheckers = [c for c in checkers if implements(c, IRawChecker)
+                       and c is not self]
         # notify global begin
         for checker in checkers:
             checker.open()
             if implements(checker, IASTNGChecker):
                 walker.add_checker(checker)
-            if implements(checker, IRawChecker) and checker is not self: #XXX
-                rawcheckers.append(checker)
         # build ast and check modules or packages
         for descr in self.expand_files(files_or_modules):
             modname, filepath = descr['name'], descr['path']
@@ -532,11 +536,11 @@ This is used by the global evaluation report (RP0004).'}),
             return MANAGER.astng_from_file(filepath, modname, source=True)
         except SyntaxError, ex:
             self.add_message('E0001', line=ex.lineno, args=ex.msg)
-        except KeyboardInterrupt:
-            raise
+        except ASTNGBuildingException, ex:
+            self.add_message('F0010', args=ex)
         except Exception, ex:
-            # import traceback
-            # traceback.print_exc()
+            import traceback
+            traceback.print_exc()
             self.add_message('F0002', args=(ex.__class__, ex))
 
     def check_astng_module(self, astng, walker, rawcheckers):
@@ -546,10 +550,9 @@ This is used by the global evaluation report (RP0004).'}),
             self.add_message('I0001', args=astng.name)
         else:
             #assert astng.file.endswith('.py')
-            stream = open(astng.file, 'U')
             # invoke IRawChecker interface on self to fetch module/block
             # level options
-            self.process_module(stream)
+            self.process_module(astng)
             if self._ignore_file:
                 return False
             # walk ast to collect line numbers
@@ -557,8 +560,7 @@ This is used by the global evaluation report (RP0004).'}),
             self._module_msgs_state = {}
             self.collect_block_lines(astng, orig_state)
             for checker in rawcheckers:
-                stream.seek(0)
-                checker.process_module(stream)
+                checker.process_module(astng)
         # generate events to astng checkers
         walker.walk(astng)
         return True
@@ -876,10 +878,7 @@ been issued by analysing pylint output status code
         * disable reports
         * do not save execution information
         """
-        self.linter.disable_noerror_messages()
-        self.linter.disable('miscellaneous')
-        self.linter.set_option('reports', False)
-        self.linter.set_option('persistent', False)
+        self.linter.error_mode()
 
     def cb_generate_config(self, *args, **kwargs):
         """optik callback for sample config file generation"""
