@@ -32,6 +32,7 @@ from logilab.astng import nodes, Module
 
 from pylint.checkers import EmptyReport
 
+
 class UnknownMessage(Exception):
     """raised when a unregistered message id is encountered"""
 
@@ -120,7 +121,7 @@ class MessagesHandlerMixIn:
         Keys are message ids, values are a 2-uple with the message type and the
         message itself
 
-        message ids should be a string of len 4, where the to first characters
+        message ids should be a string of len 4, where the two first characters
         are the checker id and the two last the message id in this checker
         """
         msgs_dict = checker.msgs
@@ -288,7 +289,7 @@ class MessagesHandlerMixIn:
     def print_full_documentation(self):
         """output a full documentation in ReST format"""
         by_checker = {}
-        for checker in self.sort_checkers():
+        for checker in self.get_checkers():
             if checker.name == 'master':
                 prefix = 'Main '
                 print "Options"
@@ -343,7 +344,7 @@ class MessagesHandlerMixIn:
     def list_messages(self):
         """output full messages list documentation in ReST format"""
         msgids = []
-        for checker in self.sort_checkers():
+        for checker in self.get_checkers():
             for msgid in checker.msgs.keys():
                 msgids.append(msgid)
         msgids.sort()
@@ -381,7 +382,7 @@ class ReportsHandlerMixIn:
         reportid = reportid.upper()
         self._reports_state[reportid] = False
 
-    def is_report_enabled(self, reportid):
+    def report_is_enabled(self, reportid):
         """return true if the report associated to the given identifier is
         enabled
         """
@@ -394,11 +395,9 @@ class ReportsHandlerMixIn:
             self.reporter.set_output(open(filename, 'w'))
         sect = Section('Report',
                        '%s statements analysed.'% (self.stats['statement']))
-        checkers = self.sort_checkers(self._reports)
-        checkers.reverse()
-        for checker in checkers:
+        for checker in self._reports:
             for reportid, r_title, r_cb in self._reports[checker]:
-                if not self.is_report_enabled(reportid):
+                if not self.report_is_enabled(reportid):
                     continue
                 report_sect = Section(r_title)
                 try:
@@ -446,7 +445,9 @@ def expand_modules(files_or_modules, black_list):
                 if filepath is None:
                     errors.append( {'key' : 'F0003', 'mod': modname} )
                     continue
-            except ImportError, ex:
+            except (ImportError, SyntaxError), ex:
+                # FIXME p3k : the SyntaxError is a Python bug and should be
+                # removed as soon as possible http://bugs.python.org/issue10588
                 errors.append( {'key': 'F0001', 'mod': modname, 'ex': ex} )
                 continue
         filepath = normpath(filepath)
@@ -464,46 +465,49 @@ def expand_modules(files_or_modules, black_list):
 
 
 class PyLintASTWalker(object):
-    def __init__(self):
+
+    def __init__(self, linter):
         # callbacks per node types
         self.nbstatements = 1
         self.visit_events = {}
         self.leave_events = {}
+        self.linter = linter
 
     def add_checker(self, checker):
-        hasvdefault = False
+        """walk to the checker's dir and collect visit and leave methods"""
+        # XXX : should be possible to merge needed_checkers and add_checker
         vcids = set()
-        hasldefault = False
         lcids = set()
+        visits = self.visit_events
+        leaves = self.leave_events
+        msgs = self.linter._msgs_state
         for member in dir(checker):
+            cid = member[6:]
+            if cid == 'default':
+                continue
             if member.startswith('visit_'):
-                cid = member[6:]
-                if cid != 'default':
-                    cbs = self.visit_events.setdefault(cid, [])
-                    cbs.append(getattr(checker, member))
-                    vcids.add(cid)
-                else:
-                    hasvdefault = getattr(checker, member)
+                v_meth = getattr(checker, member)
+                # don't use visit_methods with no activated message:
+                if hasattr(v_meth, 'checks_msgs'):
+                    if not any(msgs.get(m, True) for m in v_meth.checks_msgs):
+                        continue
+                visits.setdefault(cid, []).append(v_meth)
+                vcids.add(cid)
             elif member.startswith('leave_'):
-                cid = member[6:]
-                if cid != 'default':
-                    cbs = self.leave_events.setdefault(cid, [])
-                    cbs.append(getattr(checker, member))
-                    lcids.add(cid)
-                else:
-                    hasldefault = getattr(checker, member)
-        if hasvdefault:
+                l_meth = getattr(checker, member)
+                # don't use leave_methods with no activated message:
+                if hasattr(l_meth, 'checks_msgs'):
+                    if not any(msgs.get(m, True) for m in l_meth.checks_msgs):
+                        continue
+                leaves.setdefault(cid, []).append(l_meth)
+                lcids.add(cid)
+        visit_default = getattr(checker, 'visit_default', None)
+        if visit_default:
             for cls in nodes.ALL_NODE_CLASSES:
                 cid = cls.__name__.lower()
                 if cid not in vcids:
-                    cbs = self.visit_events.setdefault(cid, [])
-                    cbs.append(hasvdefault)
-        if hasldefault:
-            for cls in nodes.ALL_NODE_CLASSES:
-                cid = cls.__name__.lower()
-                if cid not in lcids:
-                    cbs = self.leave_events.setdefault(cid, [])
-                    cbs.append(hasldefault)
+                    visits.setdefault(cid, []).append(visit_default)
+        # for now we have no "leave_default" method in Pylint
 
     def walk(self, astng):
         """call visit events of astng checkers for the given node, recurse on
@@ -520,3 +524,4 @@ class PyLintASTWalker(object):
             self.walk(child)
         for cb in self.leave_events.get(cid, ()):
             cb(astng)
+
